<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/mots.git

return [

	// M
	'mots_description' => 'Mots et Groupes de mots',
	'mots_slogan' => 'Gestion des mots et groupes de mots dans SPIP',
];
